# aioburst
A library to limit async calls using a waterwheel approach to ensure calls maximize the rate limit

WARNING: This is an early release with minimal testing. The code is simple, but more tests are needed to make sure it works correctly.

## Usage


